/*=========================================================================

   Program: ParaView
   Module:    pqFormBuilder.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef _pqFormBuilder_h
#define _pqFormBuilder_h

#include "pqCoreExport.h"
#include <QObject>
#ifdef Q_WS_MAC
#include <QUiLoader>  // build fine with Qt install from dmg
#else
#include <QtUiTools/QUiLoader>   // CMake 2.4.3+ finds QtUiTools correctly
#endif

/// form builder that can create forms
/// dynamic and static plugins are searched
/// by default, dynamic plugins from the application directory are included in
/// the search
class PQCORE_EXPORT pqFormBuilder : public QUiLoader
{
  Q_OBJECT
public:
  pqFormBuilder(QObject* p = 0);
  ~pqFormBuilder();
  
  // overload function to create widgets
  QWidget* createWidget(const QString& className, 
                        QWidget* parent, 
                        const QString& name);
};

#endif

